@@ -7,9 +7,9 @@ from autobahn.asyncio.wamp import ApplicationSession
 from autobahn.wamp import auth
 from autobahn.asyncio.wamp import ApplicationRunner
 
-DATAPODS_WS_URI = "ws://devices.datapods.io:8088/ws";
-STUDIO_WS_URI = "ws://devices.record-evolution.com:8088/ws";
-LOCALHOST_WS_URI = "ws://reswarm-crossbar:8088";
+DATAPODS_WS_URI = "wss://cbw.datapods.io/ws-ua-usr";
+STUDIO_WS_URI = "wss://cbw.record-evolution.com/ws-ua-usr";
+LOCALHOST_WS_URI = "ws://crossbar_node1/ws-ua-usr";
 
 socketURIMap = {
     "https://studio.datapods.io": DATAPODS_WS_URI,
