@@ -4,13 +4,12 @@ from autobahn.wamp.types import PublishOptions
 from .crossbar import CrossbarConnection
 
 class Reswarm():
-    def __init__(self, serial_number=None):
-        self.serial_number = os.environ.get(
-            'DEVICE_SERIAL_NUMBER', serial_number)
+    def __init__(self, **options):
+        self.serial_number = os.environ.get('DEVICE_SERIAL_NUMBER', options.get("serial_number"))
         if self.serial_number == None:
             raise Exception("serial number is missing")
 
-        self.cb_connection = CrossbarConnection(serial_number)
+        self.cb_connection = CrossbarConnection(self.serial_number)
         self.cb_connection.start()
 
     def publish(self, topic: str, *args: list):
